==> tabular-model-3.1.6-20140903.135420-1-sources.jar: org/gcube/data/analysis/tabulardata/expression/logical/Between.java <==
package org.gcube.data.analysis.tabulardata.expression.logical;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.analysis.tabulardata.expression.Expression;
import org.gcube.data.analysis.tabulardata.expression.MalformedExpressionException;
import org.gcube.data.analysis.tabulardata.expression.Operator;
import org.gcube.data.analysis.tabulardata.expression.composite.BinaryExpression;
import org.gcube.data.analysis.tabulardata.expression.leaf.Range;
import org.gcube.data.analysis.tabulardata.model.datatype.BooleanType;
import org.gcube.data.analysis.tabulardata.model.datatype.DataType;

@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class Between extends BinaryExpression implements LogicalExpression{

	/**
	 * 
	 */
	private static final long serialVersionUID = 3990333735232048499L;

	@SuppressWarnings("unused")
	private Between() {
		super();	
	}

	public Between(Expression leftArgument, Range rightArgument) {
		super(leftArgument, rightArgument);
	}

	@Override
	public Operator getOperator() {		
		return Operator.BETWEEN;
	}
	
	@Override
	public DataType getReturnedDataType(){		
		return new BooleanType();
	}
	
	@Override
	public void validate() throws MalformedExpressionException {		
		super.validate();
		if(!(getRightArgument() instanceof Range)) throw new MalformedExpressionException("Between operation only supports Range expression as right argument. Current is "+getRightArgument());
	}
}

==> tabular-model-3.4.0-20170707.100500-37-sources.jar: org/gcube/data/analysis/tabulardata/expression/logical/Between.java <==
package org.gcube.data.analysis.tabulardata.expression.logical;

import java.util.Arrays;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.analysis.tabulardata.expression.Expression;
import org.gcube.data.analysis.tabulardata.expression.MalformedExpressionException;
import org.gcube.data.analysis.tabulardata.expression.Operator;
import org.gcube.data.analysis.tabulardata.expression.composite.MultipleArgumentsExpression;
import org.gcube.data.analysis.tabulardata.model.datatype.BooleanType;
import org.gcube.data.analysis.tabulardata.model.datatype.DataType;

@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public class Between extends MultipleArgumentsExpression implements LogicalExpression{

	/** 
	 * arguments[0] BETWEEN arguments[1] AND arguments[2]
	 * 
	 */
	
	
	private static final long serialVersionUID = 3990333735232048499L;

	@SuppressWarnings("unused")
	private Between() {
		super();	
	}

	public Between(Expression leftArgument, Expression minRangeArgument, Expression maxRangeArgument) {
		super(Arrays.asList(new Expression[]{
				leftArgument,
				minRangeArgument,
				maxRangeArgument}));
	}

	@Override
	public Operator getOperator() {		
		return Operator.BETWEEN;
	}
	
	@Override
	public DataType getReturnedDataType(){		
		return new BooleanType();
	}
	
	@Override
	public void validate() throws MalformedExpressionException {		
		super.validate();		
	}
	
	
	public Expression getLeftArgument(){
		return arguments.get(0);
	}
	
	
	public Expression getMinRangeArgument(){
		return arguments.get(1);
	}
	
	public Expression getMaxRangeArgument(){
		return arguments.get(2);
	}
		
}
